@@ -1,4 +1,4 @@
-/*	$OpenBSD: history.c,v 1.82 2019/06/28 13:34:59 deraadt Exp $	*/
+/*	$OpenBSD: history.c,v 1.86 2024/08/27 19:27:19 op Exp $	*/
 
 /*
  * command history
@@ -13,7 +13,6 @@
  */
 
 #include <sys/stat.h>
-#include <sys/uio.h>
 
 #include <errno.h>
 #include <fcntl.h>
@@ -513,20 +512,19 @@ findhist(int start, int fwd, const char *str, int anchored)
 int
 findhistrel(const char *str)
 {
+	const char *errstr;
 	int	maxhist = histptr - history;
-	int	start = maxhist - 1;
-	int	rec = atoi(str);
+	int	rec;
+
+	rec = strtonum(str, -maxhist, maxhist, &errstr);
+	if (errstr)
+		return -1;
 
 	if (rec == 0)
 		return -1;
-	if (rec > 0) {
-		if (rec > maxhist)
-			return -1;
+	if (rec > 0)
 		return rec - 1;
-	}
-	if (rec > maxhist)
-		return -1;
-	return start + rec + 1;
+	return maxhist + rec;
 }
 
 void
@@ -559,6 +557,7 @@ void
 sethistsize(int n)
 {
 	if (n > 0 && (uint32_t)n != histsize) {
+		char **tmp;
 		int offset = histptr - history;
 
 		/* save most recent history */
@@ -571,10 +570,15 @@ sethistsize(int n)
 			memmove(history, histptr - offset, n * sizeof(char *));
 		}
 
-		histsize = n;
-		histbase = areallocarray(histbase, n + 1, sizeof(char *), APERM);
-		history = histbase + 1;
-		histptr = history + offset;
+		tmp = reallocarray(histbase, n + 1, sizeof(char *));
+		if (tmp != NULL) {
+			histbase = tmp;
+			histsize = n;
+			history = histbase + 1;
+			histptr = history + offset;
+		} else
+			warningf(false, "resizing history storage: %s",
+			    strerror(errno));
 	}
 }
 
@@ -618,8 +622,10 @@ init_histvec(void)
 		 * allocate one extra element so that histptr always
 		 * lies within array bounds
 		 */
-		histbase = areallocarray(NULL, histsize + 1, sizeof(char *),
-		    APERM);
+		histbase = reallocarray(NULL, histsize + 1, sizeof(char *));
+		if (histbase == NULL)
+			internal_errorf("allocating history storage: %s",
+			    strerror(errno));
 		*histbase = NULL;
 		history = histbase + 1;
 		histptr = history - 1;
